==> apache-camel-3.13.0-src.zip: apache-camel-3.13.0/components/camel-soroush/src/main/java/org/apache/camel/component/soroushbot/utils/ExponentialBackOffStrategy.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.soroushbot.utils;

public class ExponentialBackOffStrategy implements BackOffStrategy {
    Long baseRetryTimeOut;
    Long coefficient;
    //Long maxRetryWaitingTime;

    public ExponentialBackOffStrategy(Long baseRetryTimeOut, Long coefficient, Long maxRetryWaitingTime) {
        this.baseRetryTimeOut = baseRetryTimeOut;
        this.coefficient = coefficient;
        //this.maxRetryWaitingTime = maxRetryWaitingTime;
    }

    @Override
    public void waitBeforeRetry(int retryCount) throws InterruptedException {
        //the first and second request do not need wait
        retryCount -= 2;
        if (retryCount >= 0) {
            Thread.sleep((long) (baseRetryTimeOut * Math.pow(coefficient, retryCount)));
        }
    }
}

==> apache-camel-3.14.0-src.zip: apache-camel-3.14.0/components/camel-soroush/src/main/java/org/apache/camel/component/soroushbot/utils/ExponentialBackOffStrategy.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.soroushbot.utils;

import org.apache.camel.support.task.budget.backoff.BackOffStrategy;

public class ExponentialBackOffStrategy implements BackOffStrategy {
    private final long baseRetryTimeOut;
    private final long coefficient;

    public ExponentialBackOffStrategy(Long baseRetryTimeOut, Long coefficient) {
        this.baseRetryTimeOut = baseRetryTimeOut;
        this.coefficient = coefficient;
    }

    @Override
    public long calculateInterval(int iteration) {
        //the first and second request do not need wait
        if (iteration > 2) {
            long interval = (long) (baseRetryTimeOut * Math.pow(coefficient, iteration - 2));

            return interval;
        }

        return 0;
    }
}
